Vec2

Struct Vec2 

#[repr(C)]
pub struct Vec2<F>
where F: Float,
{ pub x: F, pub y: F, }
2D Euclidian vector with X and Y components.

Fields

x: Fy: F

Implementations

Source

impl<F> Vec2<F>
where F: Float,

pub fn new(x: F, y: F) -> Self

Creates new vector.

pub fn split(&self) -> (F, F)

Splits vector into X and Y components.

pub fn combine(xy: (F, F)) -> Self

Combines tuple into vector.

pub fn into_basis(self) -> (Self, Self)

Split vector into it’s basic vectors i, j.

pub fn dot(&self, other: Self) -> F

Computes dot product between two vectors.

pub fn dot_normalized(&self, other: Self) -> F

Computes dot product between two normalized copies of the vectors.

pub fn scale(&mut self, factor: F)

Scales all of the components by factor.

pub fn magnitude(&self) -> F

Computes the magnitude of the vector.

pub fn sqrt_magnitude(&self) -> F

Computes the squared magnitude of the vector.

pub fn distance_to(&self, other: Self) -> F

Computes the distance between two vectors.

pub fn normalized(&self) -> Self

Returns the normalized version of the vector.

pub fn normalize(&mut self)

Normalizes the vector, preserving direction but reducing its magnitude to 1.